==> haskell-random-fu-0.3.0.1-106-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-random-fu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 random-fu
version:              0.3.0.1
visibility:           public
id:                   random-fu-0.3.0.1-HKyA5YdMt7o47KA8400Dgr
key:                  random-fu-0.3.0.1-HKyA5YdMt7o47KA8400Dgr
license:              LicenseRef-PublicDomain
maintainer:           Dominic Steinitz <dominic@steinitz.org>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/mokus0/random-fu
synopsis:             Random number generation
description:
    Random number generation based on modeling random
    variables in two complementary ways: first, by the
    parameters of standard mathematical distributions and,
    second, by an abstract type ('\''RVar'\'') which can be
    composed and manipulated monadically and sampled in
    either monadic or \"pure\" styles.

    The primary purpose of this library is to support
    defining and sampling a wide variety of high quality
    random variables.  Quality is prioritized over speed,
    but performance is an important goal too.

    In my testing, I have found it capable of speed
    comparable to other Haskell libraries, but still
    a fair bit slower than straight C implementations of
    the same algorithms.

category:             Math
abi:                  714e548a0798220816e20591e434147d
exposed:              True
exposed-modules:
    Data.Random Data.Random.Distribution
    Data.Random.Distribution.Bernoulli Data.Random.Distribution.Beta
    Data.Random.Distribution.Binomial
    Data.Random.Distribution.Categorical
    Data.Random.Distribution.ChiSquare
    Data.Random.Distribution.Dirichlet
    Data.Random.Distribution.Exponential Data.Random.Distribution.Gamma
    Data.Random.Distribution.Multinomial
    Data.Random.Distribution.Normal Data.Random.Distribution.Pareto
    Data.Random.Distribution.Poisson Data.Random.Distribution.Rayleigh
    Data.Random.Distribution.Simplex
    Data.Random.Distribution.StretchedExponential
    Data.Random.Distribution.T Data.Random.Distribution.Triangular
    Data.Random.Distribution.Uniform Data.Random.Distribution.Weibull
    Data.Random.Distribution.Ziggurat Data.Random.Internal.Find
    Data.Random.Internal.Fixed Data.Random.Lift Data.Random.List
    Data.Random.RVar Data.Random.Sample Data.Random.Vector

import-dirs:          /usr/lib/ghc-9.4.8/site-local/random-fu-0.3.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/random-fu-0.3.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/random-fu-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-random-fu
hs-libraries:         HSrandom-fu-0.3.0.1-HKyA5YdMt7o47KA8400Dgr
depends:
    base-4.17.2.1 erf-2.0.0.0-Eu7AY88UyC43DyrUue97pz
    math-functions-0.3.4.4-9j9uYqvjGab1srsM59hmRH
    monad-loops-0.4.3-KaRiS5mJjkQ1zBkxxbNC2Z mtl-2.2.2
    random-1.2.1.3-LY8g0he9kPzH0WCF9vQLty
    random-shuffle-0.0.4-BaYTgbpbwFo5AolR5DnuMW
    rvar-0.3.0.2-CgvJyshDYWYAOLsvit0g51
    syb-0.7.3-82kecYkSnotJhXSs3T6xq0 template-haskell-2.19.0.0
    transformers-0.5.6.2 vector-0.13.2.0-9TreTxHfwqF7cSCfMWPj9u

haddock-interfaces:   /usr/share/doc/haskell-random-fu/html/random-fu.haddock
haddock-html:         /usr/share/doc/haskell-random-fu/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-random-fu-0.3.0.1-107-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-random-fu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 random-fu
version:              0.3.0.1
visibility:           public
id:                   random-fu-0.3.0.1-LNyeCFmsWwDD58jQ1Not0w
key:                  random-fu-0.3.0.1-LNyeCFmsWwDD58jQ1Not0w
license:              LicenseRef-PublicDomain
maintainer:           Dominic Steinitz <dominic@steinitz.org>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/mokus0/random-fu
synopsis:             Random number generation
description:
    Random number generation based on modeling random
    variables in two complementary ways: first, by the
    parameters of standard mathematical distributions and,
    second, by an abstract type ('\''RVar'\'') which can be
    composed and manipulated monadically and sampled in
    either monadic or \"pure\" styles.

    The primary purpose of this library is to support
    defining and sampling a wide variety of high quality
    random variables.  Quality is prioritized over speed,
    but performance is an important goal too.

    In my testing, I have found it capable of speed
    comparable to other Haskell libraries, but still
    a fair bit slower than straight C implementations of
    the same algorithms.

category:             Math
abi:                  b9fa4b7012d5fafb2cbf076c2c3551e5
exposed:              True
exposed-modules:
    Data.Random Data.Random.Distribution
    Data.Random.Distribution.Bernoulli Data.Random.Distribution.Beta
    Data.Random.Distribution.Binomial
    Data.Random.Distribution.Categorical
    Data.Random.Distribution.ChiSquare
    Data.Random.Distribution.Dirichlet
    Data.Random.Distribution.Exponential Data.Random.Distribution.Gamma
    Data.Random.Distribution.Multinomial
    Data.Random.Distribution.Normal Data.Random.Distribution.Pareto
    Data.Random.Distribution.Poisson Data.Random.Distribution.Rayleigh
    Data.Random.Distribution.Simplex
    Data.Random.Distribution.StretchedExponential
    Data.Random.Distribution.T Data.Random.Distribution.Triangular
    Data.Random.Distribution.Uniform Data.Random.Distribution.Weibull
    Data.Random.Distribution.Ziggurat Data.Random.Internal.Find
    Data.Random.Internal.Fixed Data.Random.Lift Data.Random.List
    Data.Random.RVar Data.Random.Sample Data.Random.Vector

import-dirs:          /usr/lib/ghc-9.4.8/site-local/random-fu-0.3.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/random-fu-0.3.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/random-fu-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-random-fu
hs-libraries:         HSrandom-fu-0.3.0.1-LNyeCFmsWwDD58jQ1Not0w
depends:
    base-4.17.2.1 erf-2.0.0.0-Eu7AY88UyC43DyrUue97pz
    math-functions-0.3.4.4-DwLTHqYfkYwINvxEW30WtO
    monad-loops-0.4.3-KaRiS5mJjkQ1zBkxxbNC2Z mtl-2.2.2
    random-1.2.1.3-5Vfv7B7ZdGT6rasffmKWRk
    random-shuffle-0.0.4-8wopXW46yZFLbajN42JiCp
    rvar-0.3.0.2-GlgC4zzSahzE4OVKpII6hX
    syb-0.7.3-DvMMPSfjQylGDaZxljQ4qT template-haskell-2.19.0.0
    transformers-0.5.6.2 vector-0.13.2.0-LerqRcvS8LMBGXOi8GqDsa

haddock-interfaces:   /usr/share/doc/haskell-random-fu/html/random-fu.haddock
haddock-html:         /usr/share/doc/haskell-random-fu/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
